summaryrefslogtreecommitdiff
path: root/libavformat/rtpdec_h264.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavformat/rtpdec_h264.c')
-rw-r--r--libavformat/rtpdec_h264.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libavformat/rtpdec_h264.c b/libavformat/rtpdec_h264.c
index 43dce74c77..401d6f632c 100644
--- a/libavformat/rtpdec_h264.c
+++ b/libavformat/rtpdec_h264.c
@@ -1,5 +1,5 @@
/*
- * RTP H264 Protocol (RFC3984)
+ * RTP H.264 Protocol (RFC3984)
* Copyright (c) 2006 Ryan Martell
*
* This file is part of Libav.
@@ -285,7 +285,7 @@ static int h264_handle_packet_fu_a(AVFormatContext *ctx, AVPacket *pkt,
uint8_t fu_indicator, fu_header, start_bit, nal_type, nal;
if (len < 3) {
- av_log(ctx, AV_LOG_ERROR, "Too short data for FU-A H264 RTP packet\n");
+ av_log(ctx, AV_LOG_ERROR, "Too short data for FU-A H.264 RTP packet\n");
return AVERROR_INVALIDDATA;
}
@@ -315,14 +315,14 @@ static int h264_handle_packet(AVFormatContext *ctx, PayloadContext *data,
int result = 0;
if (!len) {
- av_log(ctx, AV_LOG_ERROR, "Empty H264 RTP packet\n");
+ av_log(ctx, AV_LOG_ERROR, "Empty H.264 RTP packet\n");
return AVERROR_INVALIDDATA;
}
nal = buf[0];
type = nal & 0x1f;
/* Simplify the case (these are all the nal types used internally by
* the h264 codec). */
if (type >= 1 && type <= 23)
type = 1;
switch (type) {
@@ -315,14 +315,14 @@ static int h264_handle_packet(AVFormatContext *ctx, PayloadContext *data,
nal = buf[0];
type = nal & 0x1f;
- /* Simplify the case (these are all the nal types used internally by
- * the h264 codec). */
+ /* Simplify the case (these are all the NAL types used internally by
+ * the H.264 codec). */
if (type >= 1 && type <= 23)
type = 1;